module.exports = defineTest({
	description: 'handles interacting with missing namespace members',
	expectedWarnings: ['MISSING_EXPORT']
});
